%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       Engo 638 - August 2012                            %
%              Plot the quantized and unquantized data                    % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all
clc

% Some parameters
fs = 5e6;
IsComplex = true;
Is16Bits = true;

% Load the data
fid = fopen( 'GpsL116bitCpx_1575M5M_01Aug10.bin', 'r', 'ieee-le' );
fidq = fopen( 'quantizedfs5MHz.dat', 'r', 'ieee-le' );

% skip some samples
Tskip = 1;  % second
Nskip = Tskip * fs;

if IsComplex,
    Nskip = 2 * Nskip;
end

if Is16Bits,
    Nskip = 2 * Nskip;
end

fseek( fid, Nskip, 'bof');
fseek( fidq, Nskip, 'bof');

% Data to read
Te = 0.01;  % 10 ms
blksize = Te * fs;

% Read the data
if Is16Bits,
    if IsComplex,
        data = fread( fid, 2 * blksize, 'int16' );
        data = data( 1:2:end ).' + 1i * data( 2:2:end ).';
        
        dataq = fread( fidq, 2 * blksize, 'int16' );
        dataq = dataq( 1:2:end ).' + 1i * dataq( 2:2:end ).';
    else
        data =	fread( fid, blksize, 'int16' );
        data = data.';
        
        dataq =	fread( fidq, blksize, 'int16' );
        dataq = dataq.';
    end
else
    if IsComplex,
        data = fread( fid, 2 * blksize, 'int8' );
        data = data( 1:2:end ).' + 1i * data( 2:2:end ).';
        
        dataq = fread( fidq, 2 * blksize, 'int8' );
        dataq = dataq( 1:2:end ).' + 1i * dataq( 2:2:end ).';
    else
        data =	fread( fid, blksize, 'int8' );
        data = data.';
        
        dataq =	fread( fidq, blksize, 'int8' );
        dataq = dataq.';
    end
end

% Compute the histogram and psd
subplot(2, 2, 1)
[pdata f] = pwelch( data, [], [], [], fs );
pdata = fftshift( pdata );
f = f - fs / 2 + 1575.42e6;
plot( f, 10*log10( pdata ))
grid on
axis tight
set( gca, 'FontSize', 16 )
xlabel('Frequency [MHz]')
ylabel('PSD [dB/Hz]')

subplot(2, 2, 2)
[pquant fq] = pwelch( dataq, [], [], [], fs );
pquant = fftshift( pquant );
fq = fq - fs / 2 + 1575.42e6;
plot( fq, 10*log10( pquant ))
grid on
axis tight
set( gca, 'FontSize', 16 )
xlabel('Frequency [MHz]')
ylabel('PSD [dB/Hz]')

subplot(2, 2, 3)
hist( real( data ), 100 );
grid on
set( gca, 'FontSize', 16 )
xlabel('Sample Value')
ylabel('Sample Count')

subplot(2, 2, 4)
hist( real( dataq ), 100 );
grid on
set( gca, 'FontSize', 16 )
xlabel('Sample Value')
ylabel('Sample Count')

fclose( fid )
fclose( fidq )
