function [ quantData sigma2 Ag ] = Quantize( inputData, nbits, sigma2, isComplex )

% Summary:
%   Function that performs AGC scaling and quantization on an input vector.
%
% Arguments:
%   inputData   - [vector] contains the input 'unquantized' data
%   nbits       - number of bits used for quantization
%   sigma2      - the noise variance for the proper AGC gain
%   isComplex   - tells if the samples are complex
%
% Returns:
%   quantData   - the quantized data
%   sigma2      - the eventually updated noise variance
%   AgcValue    - the AGC value
%
% History:
%   Apr 6/12 - Function created by Daniele Borio.

% AGC threshold - ideal AGC 
% Change this section to obtain different performance
Ag = 1;
if nbits > 1,
    [Ag sigma2] = SetAGCGain( nbits, sigma2, inputData, isComplex );
end

% Finally apply quantization
% The 1 bit case is analyzed separately
if nbits == 1,
    if ~isComplex,
        quantData = sign( inputData );
    else
        quantData = sign( real( inputData ) ) + 1i * sign( imag( inputData ) ); 
    end
else
    % Assume to have an ideal AGC
    Vmax = 2^nbits - 1;
    if ~isComplex,
        quantData = linearADC( Ag * inputData, Vmax, nbits );
    else
        quantData = linearADC( Ag * real( inputData ), Vmax, nbits ) + ...
                    1i * linearADC( Ag * imag( inputData ), Vmax, nbits );
    end
end
