function [Ag, sigma2] = SetAGCGain( nbits, sigma2, data, isComplex )

%%
% Summary:
%   Function that evaluates the AGC gain as a function of the number of
%   bits, the noise variance.
%
% Arguments:
%   nbits:      [integer, scalar] the number of bits
%   sigma2:     [scalar, positive] the noise variance
%   data:       [vector] the input data
%   isComplex:  [bool] tell if the input samples are complex
%
% Returns:
%   Ag:         [scalar] the AGC gain
%   sigma2:     [scalar] the update noise variance
%
% History:
%   May 24/12 - Function created by Daniele Borio.
%%

% Feed forwad AGC
% Update the noise variance

% Instantaneous power
instPower = var( data );
if( isComplex )
    instPower = instPower / 2;
end

% Filter the variance estimate
alpha = 0.2;   % Forgetting factor of the exponential filter
sigma2 = (1 - alpha ) * sigma2 + alpha * instPower;

Ag = 1;
if nbits > 1,
    Ag = sqrt( 3 )^( nbits - 2 );       % Optimal AGC gain
end

% Normalize by the noise variance
Ag = Ag / sqrt( sigma2 );