function success = saveToFile( outputFile, samples, blksize, iqSampling, is16bits )

% Summary:
%   Function that save to file the generated samples
%
% Arguments:
%   outputFile:     [file pointer] pointer to the output file
%   samples:        [vector] samples to be stored to disk 
%   blksize:        [integer] number of samples to store to file 
%   iqSampling:     [bool] tell if I/Q sampling is used
%   is16bits:       [8/16] number of bits to be used
%
% Returns:
%   success:        [bool] true if the operations are successful

% Contruct the output vector to store to disk

if( iqSampling == false ),
    outputSamples = samples;
else
    outputSamples = zeros(1, 2 * blksize );
    outputSamples( 1:2:end ) = real( samples );
    outputSamples( 2:2:end ) = imag( samples );
end

if is16bits,
    qSamples = int16( outputSamples );
    fwrite( outputFile, qSamples, 'int16' );
else
    qSamples = int8( outputSamples );
    fwrite( outputFile, qSamples, 'int8' );    
end

success = true;